<h1>starter notes, "canvas"</h1>

<details>
    <summary>        
        <sub>
            (what is this?)
        </sub>
    </summary>
        <div>
            <sub>
                intrapreneur canvas, capture expectations, build common understanding of "the big picture around the work"

                <p />
                at start of (our part of) a product lifecycle, or starting up a service etc.
            </sub>
        </div>
</details>

<div>
    <kbd align=left>
        <h2>purpose</h2>
        <details>            
            <summary>
                <sub>
                    (why..)
                </sub>                    
            </summary>  

* <sub>ca what is the aim of the effort?  what value/ impact/ outcome/ benefit is desired? </sub>
* <sub>ca what is the goal for team contribution?</sub>

</details>  

* test
* ...

<p>
    notes...
</p>
    </kbd>
</div>


<div align=right>
    <kbd align=left>
        <h2>timing</h2>
        <details>            
            <summary>
                <sub>
                    (what..)
                </sub>                    
            </summary>  

* <sub>ca what value/ impact/ outcome is desired? </sub>
* <sub>_ca_ what contribution from team is desired?</sub>

</details>  

* test
* ...

<p>
    notes...
</p>
    </kbd>
</div>





notes

NB: ikkje dupliser AC-tema...

still notes - important topics to include

* people
  * team
  * TL
  * nearest pri stakeholder?
  * others? project manager?
  * cadences
* timing, scope, context
  * horizon (calendar)
  * project context? decision gates?
  * hard deadlines?
  * can scope be easily modified (by PO/pri.stakeholder)
* tech
  * data - classification? amount? sources?
  * dependencies - systems, teams?
* budget
  * WBS?
  * funding/ budget - ca how much? ca how long? (currently believe)
  * what kind of limit? (fixed for the year? per time unit, f.ex month?)
* AC - incl some topics
* notes - features, mvp?
  * solution, minimal ok scope?
* notes - misc
